@@ -1,11 +1,11 @@
 #ifndef _RAR_VOLUME_
 #define _RAR_VOLUME_
 
-void SplitArchive(Archive &Arc,FileHeader *fh,Int64 *HeaderPos,
+void SplitArchive(Archive &Arc,FileHeader *fh,int64 *HeaderPos,
                   ComprDataIO *DataIO);
 bool MergeArchive(Archive &Arc,ComprDataIO *DataIO,bool ShowFileName,
                   char Command);
-void SetVolWrite(Archive &Dest,Int64 VolSize);
-bool AskNextVol(char *ArcName);
+void SetVolWrite(Archive &Dest,int64 VolSize);
+bool AskNextVol(char *ArcName,wchar *ArcNameW);
 
-#endif
\ No newline at end of file
+#endif
